﻿/// <reference path="ImgEdit-vsdoc.js"/>
/// <reference path="ImgThumbnails-vsdoc.js"/>
/// <reference path="ImgScan-vsdoc.js"/>
/// <reference path="ImgAnnotations-vsdoc.js"/>
/// <reference path="ImgBarDecoder-vsdoc.js"/>
var _webServiceURL = "../../ImageManagerService.svc";
var _imgEdit = null;
var _imgThumbnails = null;
var _imgScan = null;
var _imgAnnotations = null;
var _imgBarDecoder = null;
//Comment the following lines on release. This is just for intellisense purposes.
_imgEdit = new ImgEdit();
_imgThumbnails = new ImgThumbnails();
_imgScan = new ImgScan();
_imgAnnotations = new ImgAnnotations();
_imgBarDecoder = new ImgBarDecoder();

var _isImgScanDownloading = false;

function pageLoad() {
    //Get the ImgEdit control.
    _imgEdit = $find('ImgEdit1');
    //Get the ImgThumbnail control.
    _imgThumbnails = $find('ImgThumbnails1');
    //Get the ImgScan control.
    _imgScan = $find('ImgScan1');
    //Get the ImgAnnotations control.
    _imgAnnotations = $find('ImgAnnotations1');
    //Get the ImgBarDecoder control.
    _imgBarDecoder = $find('ImgBarDecoder1');
    _imgThumbnails.ImgEditComponent = _imgEdit;
    _imgEdit.set_WebServiceURL(_webServiceURL);
    _imgEdit.addEventListener("ErrorOccurred", onErrorOccurred);
    _imgScan.ImgEditComponent = _imgEdit;
    _imgAnnotations.ImgEditComponent = _imgEdit;
    _imgBarDecoder.ImgEditComponent = _imgEdit;
}

function openImage() {
    _imgEdit.DisplayUrl(document.location.protocol + '//documents.imagecomponents.net/Doc.tif');
    _imgEdit.FitTo(ImgEdit.ICImageFit.BESTFIT, true);
}

function scanImage() {
    //Close existing image if open.
    _imgEdit.Close();
    if (_imgScan.ConnectionStatus !== ImgScan.ICWSocketStatus.CONNECTED) {
        _imgScan.OpenConnection(function () {
            _imgScan.ActiveSourceName = "TWAIN2 FreeImage Software Scanner";
            _imgScan.DeviceDriverType = ImgScan.ICDeviceDriverType.TWAIN;
            _imgScan.DeviceSettings = new ImgScan.ICDeviceSettings();
            //This is important if you are scanning a multi-page document. You can also set to PDF.
            _imgScan.DeviceSettings.OutputFormat = ImgScan.ICImageOutputFormat.TIFF;
            _imgScan.SetTwainSettings = new ImgScan.TwainValues();
            _imgScan.SetTwainSettings.TwainICapabilities.ImageXferMech = ImgScan.ICAP_XFERMECH.NATIVE;
            _imgScan.Acquire();
        });
    }
    else {
        _imgScan.ActiveSourceName = "TWAIN2 FreeImage Software Scanner";
        _imgScan.DeviceDriverType = ImgScan.ICDeviceDriverType.TWAIN;
        _imgScan.DeviceSettings = new ImgScan.ICDeviceSettings();
        //This is important if you are scanning a multi-page document. You can also set to PDF.
        _imgScan.DeviceSettings.OutputFormat = ImgScan.ICImageOutputFormat.TIFF;
        _imgScan.SetTwainSettings = new ImgScan.TwainValues();
        _imgScan.SetTwainSettings.TwainICapabilities.ImageXferMech = ImgScan.ICAP_XFERMECH.NATIVE;
        _imgScan.Acquire();
    }
}

function addAnnotation() {
    _imgAnnotations.EnableAnnotationType = ImgAnnotations.ICAnnotationType.HighlightAnnotation;
    _imgEdit.EnableSelectionType = ImgEdit.ICSelectionType.ANNOTATIONSELECTION;
}

function readBarcodes() {
    _imgBarDecoder.ImageBarcodeTypes = [];
    _imgBarDecoder.ImageBarcodeTypes.push(ImgBarDecoder.ICImageBarcodeType.CODE39);
    _imgBarDecoder.ImageBarcodeOrientations = [];
    _imgBarDecoder.ImageBarcodeOrientations.push(ImgBarDecoder.ICImageBarcodeOrientation.LEFTTORIGHT);
    _imgBarDecoder.StopOnFirstResult = false;
    _imgBarDecoder.ExtensiveSearch = true;
    _imgBarDecoder.EnableCheckDigit = false;
    _imgBarDecoder.ImageBarcodePageType = ImgBarDecoder.ICImageBarcodePageType.SELECTEDPAGE;
    _imgBarDecoder.ReadBarcodes();
}

function getEnumValue(enumObj, key) {
    for (var obj in enumObj) {
        if (enumObj[obj] === key) {
            return obj;
        }
    }
    return null;
}

//This events are hired up on the html control definition.

//On web socket connection.
function onSocketStatusChanged(s, e) {
    switch (e) {
        case ImgScan.ICWSocketStatus.CONNECTING:

            break;
        case ImgScan.ICWSocketStatus.CONNECTED:

            break;
        case ImgScan.ICWSocketStatus.CONNECTIONERROR:
            if (_isImgScanDownloading == false) {
                if (confirm('Could not connect to the ImgScan twain bridge plugin.\r\nDo you want to download the installation package and try again?')) {
                    var win = window.open(document.location.protocol + "//install.imagecomponents.net/ImgScanPluginX86.msi", "_blank");
                    win.focus();
                } else {
                    _imgScan.CloseConnection();
                }
            }
            break;
        case ImgScan.ICWSocketStatus.RECONNECTING:

            break;
    }
}

//On scan finished event.
function onScanFinished(s, e) {
    //Upload the image to your server.
    var _base64Image = e.Stream;
}

//On barcode scan finished event.
function onBarcodeScanFinished(s, e) {
    if (_imgBarDecoder.ReadedBarcodesResults != null && _imgBarDecoder.ReadedBarcodesResults.length > 0) {
        var _resultValue = "";

        for (var i = 0; i < _imgBarDecoder.ReadedBarcodesResults.length; i++) {
            var _result = _imgBarDecoder.ReadedBarcodesResults[i];
            _resultValue += "Barcode type: " + getEnumValue(ImgBarDecoder.ICImageBarcodeType, _result.BarcodeType) + "\r\n" +
                            "Barcode result: " + _result.Text + "\r\n\r\n";
        }
        alert(_resultValue);
    }
}

//On error occurred event.
function onErrorOccurred(s, e) {
    alert("One error occurred in the control '" + e.ControlName + "'.\r\nThe error detail in the method '" + e.MethodName +
        "' is as follows:\r\n\r\n" + e.ErrorMessage + "\r\n\r\nSorry for this inconvenient. ");
}